@@ -24,6 +24,12 @@
 #include "gdm.h"
 #include "display.h"
 
+typedef enum {
+        GDM_SESSION_RECORD_TYPE_LOGIN,
+        GDM_SESSION_RECORD_TYPE_LOGOUT,
+        GDM_SESSION_RECORD_TYPE_FAILED_ATTEMPT
+} GdmSessionRecordType;
+
 void     gdm_slave_start       (GdmDisplay *d);
 void     gdm_slave_greeter_ctl_no_ret (char cmd, const char *str);
 char    *gdm_slave_greeter_ctl (char cmd, const char *str);
@@ -42,6 +48,12 @@ gboolean gdm_is_session_magic (const char *session_name);
 
 /* This is the slave child handler so that we can chain to it from elsewhere */
 void	 gdm_slave_child_handler (int sig);
+void     gdm_slave_write_utmp_wtmp_record (GdmDisplay *d,
+                                 GdmSessionRecordType record_type,
+                                 const gchar *username,
+                                 GPid  pid);
+gchar *  gdm_slave_get_display_device (GdmDisplay *d);
+
 
 #endif /* GDM_SLAVE_H */
 
